==> VMware-vSphere-SDK-6.7.0-7970399.zip: com/vmware/pbm/ArrayOfPbmProfileId.java <==

package com.vmware.pbm;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ArrayOfPbmProfileId complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ArrayOfPbmProfileId">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PbmProfileId" type="{urn:pbm}PbmProfileId" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ArrayOfPbmProfileId", propOrder = {
    "pbmProfileId"
})
public class ArrayOfPbmProfileId {

    @XmlElement(name = "PbmProfileId")
    protected List<PbmProfileId> pbmProfileId;

    /**
     * Gets the value of the pbmProfileId property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the pbmProfileId property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPbmProfileId().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PbmProfileId }
     * 
     * 
     */
    public List<PbmProfileId> getPbmProfileId() {
        if (pbmProfileId == null) {
            pbmProfileId = new ArrayList<PbmProfileId>();
        }
        return this.pbmProfileId;
    }

}

==> VMware-vSphere-SDK-8.0.1-21562244.zip: com/vmware/pbm/ArrayOfPbmProfileId.java <==

package com.vmware.pbm;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ArrayOfPbmProfileId complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ArrayOfPbmProfileId"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="PbmProfileId" type="{urn:pbm}PbmProfileId" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ArrayOfPbmProfileId", propOrder = {
    "pbmProfileId"
})
public class ArrayOfPbmProfileId {

    @XmlElement(name = "PbmProfileId")
    protected List<PbmProfileId> pbmProfileId;

    /**
     * Gets the value of the pbmProfileId property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a <CODE>set</CODE> method for the pbmProfileId property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPbmProfileId().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PbmProfileId }
     * 
     * 
     */
    public List<PbmProfileId> getPbmProfileId() {
        if (pbmProfileId == null) {
            pbmProfileId = new ArrayList<PbmProfileId>();
        }
        return this.pbmProfileId;
    }

}
